@@ -1,6 +1,6 @@
 import re
 import sys
-from configparser import ConfigParser, NoOptionError, NoSectionError
+from configparser import ConfigParser
 from datetime import datetime
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
@@ -15,7 +15,7 @@ from ..errors import (
     SamlClientNotSetup,
     UnavailableResourceError,
 )
-from ..helpers.config import Config, SymConfigFile, xdg_config_home
+from ..helpers.config import Config, SymConfigFile
 from ..helpers.constants import AwsOktaNoCreds, AwsOktaNoRoles, AwsOktaNotSetup
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument
@@ -49,7 +49,7 @@ class AwsOkta(SAMLClient):
 
     def is_setup(self) -> bool:
         path = Path.home() / ".aws" / "config"
-        config = ConfigParser()
+        config = ConfigParser(strict=False)
         config.read(path)
         return "okta" in config.sections()
 
@@ -73,7 +73,6 @@ class AwsOkta(SAMLClient):
     def _exec(
         self, *args: str, debug_: bool = False, **opts: str
     ) -> Iterator[Tuple[Argument, ...]]:
-        self.log_subprocess_event(args)
         self.ensure_config()
         with push_env("AWS_CONFIG_FILE", str(self.config_file)):
             yield (
@@ -88,7 +87,13 @@ class AwsOkta(SAMLClient):
 
     def _get_session_id(self):
         try:
-            self._exec("false", capture_output_=True, debug_=True)
+            self._exec(
+                "false",
+                capture_output_=True,
+                debug_=True,
+                run_subprocess_options_=self.options,
+                intercept_errors_options_=self.options,
+            )
         except FailedSubprocessError as err:
             if match := SessionIDPattern.search(err.__cause__.stderr):
                 return match[1]
@@ -145,6 +150,12 @@ class AwsOkta(SAMLClient):
         url = self.get_aws_saml_url(bare=False)
         return urlsplit(url).netloc
 
+    @property
+    def _session_ttl(self) -> Optional[str]:
+        if self.session_length:
+            return f"{self.session_length}m"
+        return get_aws_okta_params().get("session_ttl")
+
     def _ensure_config(self, profile: Profile) -> ConfigParser:
         config = ConfigParser(default_section="okta")
         config.read_dict(
@@ -155,6 +166,7 @@ class AwsOkta(SAMLClient):
                     "region": profile.region,
                     "role_arn": profile.arn,
                     **get_aws_okta_params(),
+                    "session_ttl": self._session_ttl,
                 },
             }
         )
