@@ -1,23 +1,26 @@
 import random
 from contextlib import contextmanager
 
+import boto3
 import pytest
 from expects import *
 
 from sym.cli.sym import sym as click_command
 from sym.cli.tests.matchers import succeed
 
-INSTANCES = [
-    "i-052113589d5e8b832",
-    "i-06ee7489efaeb582e",
-    "i-0f3913172f1f4d1c0",
-    "i-0da5718079be3162c",
-    "i-03371cb517e30eb22",
-    "i-0e717dd52e0186713",
-    "i-03c087811b23a2a4f",
-    "i-08b3c84ebd6645df6",
-    "i-0f5d63478e7cb781b",
-]
+
+def gen_instances():
+    ec2 = boto3.client("ec2")
+    paginator = ec2.get_paginator("describe_instances")
+    for response in paginator.paginate(
+        Filters=[{"Name": "tag:CLITest", "Values": ["integration"]}]
+    ):
+        for reservation in response["Reservations"]:
+            for instance in reservation["Instances"]:
+                yield instance["InstanceId"]
+
+
+INSTANCES = list(gen_instances())
 
 
 @pytest.fixture
